unofficial mirror of meta@public-inbox.org
 help / color / mirror / Atom feed
* [PATCH] mbox: clarify our use of the the mboxrd variant
@ 2015-08-23  1:55 Eric Wong
  0 siblings, 0 replies; only message in thread
From: Eric Wong @ 2015-08-23  1:55 UTC (permalink / raw)
  To: meta

Commenting it in the From: line seems appropriate and
reduces compatibility problems in case a MUA cannot handle
trailing comments after the timestamp.
---
 lib/PublicInbox/Mbox.pm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lib/PublicInbox/Mbox.pm b/lib/PublicInbox/Mbox.pm
index 332e89a..9af9279 100644
--- a/lib/PublicInbox/Mbox.pm
+++ b/lib/PublicInbox/Mbox.pm
@@ -1,6 +1,6 @@
 # Copyright (C) 2015, all contributors <meta@public-inbox.org>
 # License: AGPLv3 or later (https://www.gnu.org/licenses/agpl-3.0.txt)
 # Streaming interface for formatting messages as an mbox
 package PublicInbox::Mbox;
 use strict;
 use warnings;
@@ -36,7 +36,7 @@ sub emit_msg {
 
 	my $buf = $simple->header_obj->as_string;
 	unless ($buf =~ /\AFrom /) {
-		$fh->write("From a\@a Thu Jan  1 00:00:00 1970\n");
+		$fh->write("From mboxrd\@z Thu Jan  1 00:00:00 1970\n");
 	}
 	$fh->write($buf .= $simple->crlf);
 
@@ -1,6 +1,6 @@
 # Copyright (C) 2015, all contributors <meta@public-inbox.org>
 # License: AGPLv3 or later (https://www.gnu.org/licenses/agpl-3.0.txt)
-# Streaming interface for formatting messages as an mbox
+# Streaming interface for formatting messages as an mboxrd
 package PublicInbox::Mbox;
 use strict;
-- 
EW


^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2015-08-23  1:55 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2015-08-23  1:55 [PATCH] mbox: clarify our use of the the mboxrd variant Eric Wong

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).